"""
This file imports glfw and converts constant and function names to the style
of the GLFW C API, adding GLFW_ and glfw prefixes and using CamelCase for
function names.

This file is only needed to be run when adding functions to the wrapper.
"""

from collections import OrderedDict
import glfw

constant_names = OrderedDict()
function_names = OrderedDict()
constant_type = int
function_type = type(glfw.init)
for pythonic_name in sorted(dir(glfw)):
    if pythonic_name.startswith('_'):
        continue
    obj = getattr(glfw, pythonic_name)
    if isinstance(obj, function_type):
        if pythonic_name == 'get_joystick_guid':
            cstyle_name = 'glfwGetJoystickGUID'
        else:
            cstyle_name = 'glfw' + ''.join(word.title() for word in pythonic_name.split('_'))
        function_names[pythonic_name] = cstyle_name
    elif isinstance(obj, constant_type):
        cstyle_name = 'GLFW_' + pythonic_name
        constant_names[pythonic_name] = cstyle_name
print('""" Automatically generated C-style module for pyGLFW """')
print('from . import (')
for pythonic_name, cstyle_name in constant_names.items():
    print('    {} as {},'.format(pythonic_name, cstyle_name))
for pythonic_name, cstyle_name in function_names.items():
    print('    {} as {},'.format(pythonic_name, cstyle_name))
print(')')



from setuptools import setup

setup(
    name='glfw_preview',
    version='0.0.3',
    description='A helper package for the glfw package.',
    long_description='This is a helper package for the glfw package that enables wrappers for unreleased GLFW3 macros and functions.',
    url='https://github.com/FlorianRhiem/pyGLFW',
    author='Florian Rhiem',
    author_email='florian.rhiem@gmail.com',
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: MacOS X',
        'Environment :: X11 Applications',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Multimedia :: Graphics',
        'Topic :: Scientific/Engineering :: Visualization',
    ],
    packages=['glfw_preview'],
)



from setuptools import setup
import os.path

setup_directory = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(setup_directory, 'README.rst')) as readme_file:
    long_description = readme_file.read()

setup(
    name='glfw',
    version='2.8.0',
    description='A ctypes-based wrapper for GLFW3.',
    long_description=long_description,
    url='https://github.com/FlorianRhiem/pyGLFW',
    author='Florian Rhiem',
    author_email='florian.rhiem@gmail.com',
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: MacOS X',
        'Environment :: X11 Applications',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Multimedia :: Graphics',
        'Topic :: Scientific/Engineering :: Visualization',
    ],
    packages=['glfw'],
    package_data={
        # include GLFW shared library and Visual C++ runtimes in wheel package
        'glfw': [
            'glfw3.dll',
            'libglfw.3.dylib',
            'wayland/libglfw.so',
            'x11/libglfw.so',
            'libglfw.so',
            'msvcr120.dll',
        ]
    },
    extras_require={
        'preview': ['glfw_preview']
    }
)
